#[non_exhaustive]pub struct InsightActionLog {
pub actor: String,
pub state: State,
pub state_metadata: HashMap<String, String>,
pub insight: String,
/* private fields */
}Expand description
Log content of an action on an insight. This includes Mark* actions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actor: StringRequired. User that executed this action. Eg, foo@gmail.com
state: StateRequired. State change that was made by the actor. Eg, ACCEPTED.
state_metadata: HashMap<String, String>Optional. Metadata that was included with the action that was taken.
insight: StringRequired. Name of the insight which was acted on. Eg, : ‘projects/123/locations/global/insightTypes/roleInsight/insights/i1’
Implementations
Sourceimpl InsightActionLog
impl InsightActionLog
Sourcepub fn set_state_metadata<T, K, V>(self, v: T) -> Self
pub fn set_state_metadata<T, K, V>(self, v: T) -> Self
Sets the value of state_metadata.
Example
ⓘ
let x = InsightActionLog::new().set_state_metadata([
("key0", "abc"),
("key1", "xyz"),
]);Trait Implementations
Sourceimpl Clone for InsightActionLog
impl Clone for InsightActionLog
Sourcefn clone(&self) -> InsightActionLog
fn clone(&self) -> InsightActionLog
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InsightActionLog
impl Debug for InsightActionLog
Sourceimpl Default for InsightActionLog
impl Default for InsightActionLog
Sourcefn default() -> InsightActionLog
fn default() -> InsightActionLog
Returns the “default value” for a type. Read more
Sourceimpl Message for InsightActionLog
impl Message for InsightActionLog
Sourceimpl PartialEq for InsightActionLog
impl PartialEq for InsightActionLog
Sourcefn eq(&self, other: &InsightActionLog) -> bool
fn eq(&self, other: &InsightActionLog) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InsightActionLog